@@ -3,6 +3,8 @@ if (getRversion() >= "3.1.0") {
                            "expectedFile", "filesize.x", "filesize.y", "result"))
 }
 
+defaultGitRepoToSpaDESModules <- "PredictiveEcology/SpaDES-modules"
+
 #' Find the latest module version from a SpaDES module repository
 #'
 #' Modified from \url{http://stackoverflow.com/a/25485782/1380598}.
@@ -64,7 +66,8 @@ setMethod(
 setMethod("getModuleVersion",
           signature = c(name = "character", repo = "missing"),
           definition = function(name) {
-            v <- getModuleVersion(name, getOption("spades.moduleRepo"))
+            v <- getModuleVersion(name, getOption("spades.moduleRepo",
+                                                  defaultGitRepoToSpaDESModules))
             return(v)
 })
 
@@ -129,7 +132,8 @@ setMethod(
 setMethod("checkModule",
           signature = c(name = "character", repo = "missing"),
           definition = function(name) {
-            v <- checkModule(name, getOption("spades.moduleRepo"))
+            v <- checkModule(name, getOption("spades.moduleRepo",
+                                             defaultGitRepoToSpaDESModules))
             return(v)
 })
 
@@ -174,7 +178,6 @@ setMethod(
     }
 
     essentialFiles <- c(
-      "data/CHECKSUMS.txt",
       paste0(name, ".R")
     ) %>%
       file.path(path, name, .)
@@ -193,6 +196,9 @@ setMethod(
         if (!is.na(version)) {
           v <- .parseModulePartial(filename = file.path(path, name, paste0(name, ".R")),
                                    defineModuleElement = "version")
+          if (isTRUE(length(v) > length(name))) {
+            v <- v[names(v) %in% name]
+          }
           result <- ifelse(v == numeric_version(version), TRUE, FALSE)
         }
       }
@@ -274,6 +280,7 @@ setGeneric("downloadModule", function(name, path, version, repo, data, quiet,
 #' @rdname downloadModule
 #' @importFrom reproducible checkPath
 #' @importFrom utils unzip zip
+#' @importFrom data.table setDF rbindlist
 setMethod(
   "downloadModule",
   signature = c(name = "character", path = "character", version = "character",
@@ -324,8 +331,9 @@ setMethod(
                             checksum.y = character(0), algorithm.x = character(0),
                             algorithm.y = character(0),
                             stringsAsFactors = FALSE)
+    dataList3 <- dataList2
     if (!is.null(children)) {
-      if (all(nzchar(children) & !is.na(children))) {
+      if (all(nzchar(children) & !is.na(children)) && length(children)) {
         tmp <- lapply(children, function(x) {
           f <- if (!is.null(childVersions[[x]])) {
             downloadModule(x, path = path, repo = repo, data = data, version = childVersions[[x]],
@@ -335,7 +343,8 @@ setMethod(
                            overwrite = overwrite)
           }
           files2 <<- append(files2, f[[1]])
-          dataList2 <<- bind_rows(dataList2, f[[2]])
+#          dataList2 <<- bind_rows(dataList2, f[[2]])
+          dataList2 <<- setDF(rbindlist(list(dataList2, f[[2]]), use.names = TRUE, fill = TRUE))
         })
       }
     }
@@ -362,7 +371,9 @@ setMethod(
     }
     message(crayon::magenta("Download complete for module ", name, " (v", version, ").", sep = ""))
 
-    return(list(c(files, files2), bind_rows(dataList, dataList2)))
+    return(list(c(files, files2),
+                setDF(rbindlist(list(dataList, dataList2), use.names = TRUE, fill = TRUE))))
+#                bind_rows(dataList, dataList2)))
 })
 
 #' @rdname downloadModule
@@ -374,7 +385,8 @@ setMethod(
   definition = function(name, quickCheck, overwrite) {
     files <- downloadModule(name, path = getOption("spades.modulePath"),
                             version = NA_character_,
-                            repo = getOption("spades.moduleRepo"),
+                            repo = getOption("spades.moduleRepo",
+                                             defaultGitRepoToSpaDESModules),
                             data = FALSE, quiet = FALSE,
                             quickCheck = quickCheck, overwrite = overwrite)
     return(invisible(files))
@@ -390,7 +402,8 @@ setMethod(
                         overwrite) {
     if (missing(path)) path <- getOption("spades.modulePath")
     if (missing(version)) version <- NA_character_
-    if (missing(repo)) repo <- getOption("spades.moduleRepo")
+    if (missing(repo)) repo <- getOption("spades.moduleRepo",
+                                         defaultGitRepoToSpaDESModules)
     if (missing(data)) data <- FALSE
     if (missing(quiet)) quiet <- FALSE
     if (missing(quickCheck)) quickCheck <- FALSE
