@@ -157,7 +157,7 @@ setMethod(
       as.numeric_version(v) ## SpaDES < 1.3.1.9044
     } else {
       as.numeric_version(v[[module]]) ## SpaDES >= 1.3.1.9044
-  }
+    }
 })
 
 #' @export
@@ -166,8 +166,7 @@ setMethod(
   "moduleVersion",
   signature = c(module = "character", path = "missing", sim = "missing", envir = "ANY"),
   definition = function(module, envir) {
-    moduleVersion(module = module, path = getOption("spades.modulePath"),
-                  envir = envir)
+    moduleVersion(module = module, path = getOption("spades.modulePath"), envir = envir)
 })
 
 #' @export
