@@ -112,10 +112,22 @@ restartSpades <- function(sim = NULL, module = NULL, numEvents = Inf,
 
   out <- lapply(modules, function(module) {
     pp <- list()
-    moduleFolder <- file.path(modulePath(sim, module = module))
+    moduleFolder <- file.path(modulePath(sim, module = module), module)
     if (file.exists(file.path(moduleFolder, paste0(module, ".R")))) {
+      # pp[[1]] <- .parseConditional(sim, file.path(moduleFolder, paste0(module, ".R")))
       pp[[1]] <- parse(file.path(moduleFolder, paste0(module, ".R")))
       subFiles <- dir(file.path(moduleFolder, "R"), full.names = TRUE)
+
+      doesntUseNamespacing <- !.isNamespaced(sim, module)
+
+      # evaluate the rest of the parsed file
+      if (doesntUseNamespacing) {
+        out1 <- evalWithActiveCode(pp[[1]],
+                                   sim@.xData,
+                                   sim = sim)
+      }
+
+
       if (length(subFiles)) {
         pp[seq_len(length(subFiles)) + 1] <- lapply(subFiles, function(ff) parse(ff))
       }
@@ -141,7 +153,7 @@ restartSpades <- function(sim = NULL, module = NULL, numEvents = Inf,
   # Remove all added events that occurred during the events, i.e., via scheduleEvent
   sim@events <- setdiff(sim@events, unlist(sim$.addedEvents[seq_len(numMods)], recursive = FALSE))
 
-  assign(".Random.seed", sim@.xData$.randomSeed[[numMods]], envir = .GlobalEnv)
+  assign(".Random.seed", sim@.xData$._randomSeed[[numMods]], envir = .GlobalEnv)
 
   if (restart)
     sim <- spades(sim, ...)
