@@ -10,7 +10,6 @@ if (getRversion() >= "3.1.0") {
 #'
 #' @author Alex Chubaty
 #' @export
-#' @importFrom dplyr mutate
 #' @importFrom stats na.omit
 #' @importFrom utils capture.output ls.str
 #' @include simList-class.R
@@ -251,18 +250,17 @@ setReplaceMethod(
 #' @param value The object to be stored at the slot.
 #'
 #' @param hidden Logical. If TRUE, show the default core modules.
+#'
 #' @return Returns or sets the value of the slot from the \code{simList} object.
 #'
 #' @family functions to access elements of a 'simList' object
 #' @seealso \code{\link{SpaDES.core-package}}, specifically the section 1.2.7 on Modules and dependencies.
 #'
+#' @aliases simList-accessors-modules
+#' @author Alex Chubaty
 #' @export
 #' @include simList-class.R
-#' @aliases simList-accessors-modules
 #' @rdname simList-accessors-modules
-#'
-#' @author Alex Chubaty
-#'
 setGeneric("modules", function(sim, hidden = FALSE) {
   standardGeneric("modules")
 })
@@ -402,7 +400,7 @@ setMethod(
 })
 
 ################################################################################
-#' Get and set simulation parameters.
+#' Get and set simulation parameters
 #'
 #' \code{params} and \code{P} access the parameter slot in the \code{simList}.
 #' \code{params} has a replace method, so can be used to update a parameter value.
@@ -428,12 +426,11 @@ setMethod(
 #' @family functions to access elements of a 'simList' object
 #' @seealso \code{\link{SpaDES.core-package}}, specifically the section 1.2.1 on Simulation parameters.
 #'
+#' @aliases parameters
+#' @aliases simList-accessors-params
 #' @export
 #' @include simList-class.R
-#' @aliases simList-accessors-params
-#' @aliases parameters
 #' @rdname params
-#'
 setGeneric("params", function(sim) {
   standardGeneric("params")
 })
@@ -476,7 +473,6 @@ setReplaceMethod("params",
 #' @importFrom reproducible .grepSysCalls
 #' @include simList-class.R
 #' @rdname params
-#'
 P <- function(sim, module, param) {
   if (missing(sim)) stop("P takes a simList as first argument")
   if (missing(module)) {
@@ -505,22 +501,21 @@ P <- function(sim, module, param) {
   }
 }
 
-
 ################################################################################
-#' Get and set simulation globals.
+#' Get and set global simulation parameters
 #'
 #' \code{globals}, and the alias \code{G}, accesses or sets the "globals"
 #' in the \code{simList}. This currently is not an explicit slot in the \code{simList},
 #' but it is a \code{.globals} element in the \code{params} slot of the \code{simList}.
 #'
 #' @inheritParams params
-#' @include simList-class.R
-#' @export
-#' @rdname globals
 #'
 #' @family functions to access elements of a 'simList' object
 #' @seealso \code{\link{SpaDES.core-package}}, specifically the section 1.2.1 on Simulation Parameters.
 #'
+#' @export
+#' @include simList-class.R
+#' @rdname globals
 setGeneric("globals", function(sim) {
   standardGeneric("globals")
 })
@@ -540,10 +535,10 @@ setGeneric("globals<-",
              standardGeneric("globals<-")
 })
 
-#' @name globals<-
 #' @aliases globals<-,simList-method
-#' @rdname globals
 #' @export
+#' @name globals<-
+#' @rdname globals
 setReplaceMethod("globals",
                  signature = "simList",
                  function(sim, value) {
@@ -1105,7 +1100,7 @@ setReplaceMethod(
 
          for (nT in newTime) {
            attributes(nT)$unit <- timeunit(sim)
-           sim <- scheduleEvent(sim, nT, "load", "inputs", .first())
+           sim <- scheduleEvent(sim, nT, "load", "inputs", .first() - 1)
          }
          toRemove <- duplicated(rbindlist(list(current(sim), events(sim))),
                                 by = c("eventTime", "moduleName", "eventType"))
@@ -1121,7 +1116,7 @@ setReplaceMethod(
          newTime <- sim@inputs[is.na(sim@inputs$loaded), "loadTime"] %>%
            min(., na.rm = TRUE)
          attributes(newTime)$unit <- "seconds"
-         sim <- scheduleEvent(sim, newTime, "load", "inputs", .first())
+         sim <- scheduleEvent(sim, newTime, "load", "inputs", .first() - 1)
        }
      }
    }
@@ -1172,7 +1167,6 @@ setReplaceMethod(
 #'
 #' @export
 #' @include simList-class.R
-#' @importFrom dplyr inner_join
 #' @importFrom data.table := data.table
 #' @importFrom R.utils isAbsolutePath
 #' @importFrom stats na.omit
@@ -1262,27 +1256,27 @@ setMethod(
   signature = "simList",
   definition = function(sim) {
     simUnit <- sim@simtimes[["timeunit"]]
-  saveTimeUnit <- attr(sim@outputs$saveTime, "unit")
-  if (is.null(saveTimeUnit)) saveTimeUnit <- simUnit
+    saveTimeUnit <- attr(sim@outputs$saveTime, "unit")
+    if (is.null(saveTimeUnit)) saveTimeUnit <- simUnit
 
-  out <- if (is.na(pmatch(saveTimeUnit, simUnit)) &
-             length(sim@outputs$saveTime) > 0) {
-    ## note the above line captures empty saveTime, whereas is.na does not
-    if (any(!is.na(sim@outputs$saveTime))) {
-      if (!is.null(sim@outputs$saveTime)) {
-        obj <- copy(sim@outputs) # don't change original sim
-        obj[, saveTime := convertTimeunit(saveTime, unit, sim@.xData)]
-        obj[]
-        obj
+    out <- if (is.na(pmatch(saveTimeUnit, simUnit)) &
+               length(sim@outputs$saveTime) > 0) {
+      ## note the above line captures empty saveTime, whereas is.na does not
+      if (any(!is.na(sim@outputs$saveTime))) {
+        if (!is.null(sim@outputs$saveTime)) {
+          obj <- copy(sim@outputs) # don't change original sim
+          obj[, saveTime := convertTimeunit(saveTime, unit, sim@.xData)]
+          obj[]
+          obj
+        }
+      } else {
+        sim@outputs
       }
     } else {
       sim@outputs
     }
-  } else {
-    sim@outputs
-  }
-  return(out)
-})
+    return(out)
+  })
 
 #' @export
 #' @rdname simList-accessors-inout
@@ -1470,27 +1464,23 @@ setReplaceMethod(
    return(sim)
 })
 
-
-
 ################################################################################
-#' Specify paths for modules, inputs, and outputs
+#' Specify paths for modules, inputs, outputs, and temporary rasters
 #'
 #' Accessor functions for the \code{paths} slot in a \code{simList} object.
 #'
 #' These are ways to add or access the file paths used by \code{\link{spades}}.
-#' There are four file paths: \code{cachePath}, \code{modulePath},
-#' \code{inputPath}, and \code{outputPath}.
+#' There are five file paths: \code{cachePath}, \code{modulePath},
+#' \code{inputPath}, \code{outputPath}, and \code{rasterPath}.
 #' Each has a function to get or set the value in a \code{simList} object.
 #' If no paths are specified, the defaults are as follows:
 #'
 #' \itemize{
 #'   \item \code{cachePath}: \code{getOption("reproducible.cachePath")};
-#'
 #'   \item \code{inputPath}: \code{getOption("spades.modulePath")};
-#'
 #'   \item \code{modulePath}: \code{getOption("spades.inputPath")};
-#'
-#'   \item \code{inputPath}: \code{getOption("spades.outputPath")}.
+#'   \item \code{outputPath}: \code{getOption("spades.outputPath")};
+#'   \item \code{rasterPath}: \code{raster::tmpDir()}
 #' }
 #'
 #' @inheritParams params
@@ -1737,7 +1727,6 @@ setMethod("modulePath",
             } else {
               sim@paths$modulePath
             }
-
 })
 
 #' @export
@@ -1761,6 +1750,47 @@ setReplaceMethod(
     return(sim)
 })
 
+################################################################################
+#' @inheritParams paths
+#'
+#' @include simList-class.R
+#' @export
+#' @rdname simList-accessors-paths
+#' @aliases simList-accessors-paths
+setGeneric("rasterPath", function(sim) {
+  standardGeneric("rasterPath")
+})
+
+#' @export
+#' @rdname simList-accessors-paths
+#' @aliases simList-accessors-paths
+setMethod("rasterPath",
+          signature = "simList",
+          definition = function(sim) {
+            sim@paths$rasterPath
+})
+
+#' @export
+#' @rdname simList-accessors-paths
+setGeneric("rasterPath<-",
+           function(sim, value) {
+             standardGeneric("rasterPath<-")
+})
+
+#' @name rasterPath<-
+#' @aliases rasterPath<-,simList-method
+#' @aliases simList-accessors-paths
+#' @rdname simList-accessors-paths
+#' @export
+setReplaceMethod(
+  "rasterPath",
+  signature = "simList",
+  function(sim, value) {
+    sim@paths$rasterPath <- unname(unlist(value))
+    checkPath(sim@paths$rasterPath, create = TRUE)
+    validObject(sim)
+    return(sim)
+})
 
 #' @description
 #' \code{dataPath} will return \code{file.path(modulePath(sim), currentModule(sim), "data")}.
@@ -1787,7 +1817,7 @@ setMethod("dataPath",
           signature = "simList",
           definition = function(sim) {
             return(file.path(modulePath(sim, currentModule(sim)), currentModule(sim), "data"))
-          })
+})
 
 ################################################################################
 #' Time usage in \code{SpaDES}
@@ -1815,8 +1845,6 @@ setMethod("dataPath",
 #'    \code{times} \tab List of all simulation times (current, start, end, timeunit).\cr
 #' }
 #'
-#' @inheritParams objs
-#'
 #' @param unit   Character. One of the time units used in \code{SpaDES}.
 #'
 #' @param x A \code{simList}
@@ -1829,17 +1857,15 @@ setMethod("dataPath",
 #'
 #' @return Returns or sets the value of the slot from the \code{simList} object.
 #'
-#' @family functions to access elements of a 'simList' object
 #' @seealso \code{\link{SpaDES.core-package}}, specifically the section 1.2.5 on Simulation times.
 #'
+#' @aliases simList-accessors-times
+#' @author Alex Chubaty and Eliot McIntire
 #' @export
+#' @family functions to access elements of a 'simList' object
 #' @include simList-class.R
 #' @include times.R
-#' @aliases simList-accessors-times
 #' @rdname simList-accessors-times
-#'
-#' @author Alex Chubaty and Eliot McIntire
-#'
 setGeneric("times", function(x, ...) {
   standardGeneric("times")
 })
@@ -1906,8 +1932,6 @@ setReplaceMethod(
 })
 
 ################################################################################
-#' @inheritParams times
-#'
 #' @export
 #' @importFrom stats time
 #' @include simList-class.R
@@ -1930,18 +1954,18 @@ time.simList <- function(x, unit, ...) {
     return(t)
 }
 
+#' @aliases simList-accessors-times
 #' @export
 #' @rdname simList-accessors-times
-#' @aliases simList-accessors-times
 setGeneric("time<-", function(x, value) {
   standardGeneric("time<-")
 })
 
-#' @name time<-
 #' @aliases time<-,simList-method
-#' @export
-#' @rdname simList-accessors-times
 #' @aliases simList-accessors-times
+#' @export
+#' @name time<-
+#' @rdname simList-accessors-times
 setReplaceMethod(
   "time",
    signature = "simList",
@@ -1959,11 +1983,10 @@ setReplaceMethod(
 })
 
 ################################################################################
-#' @inheritParams times
-#' @include times.R
-#' @importFrom stats end
-#' @include simList-class.R
 #' @export
+#' @importFrom stats end
+#' @include times.R
+#' @include simList-class.R
 #' @rdname simList-accessors-times
 end <- function(x, ...) UseMethod("end")
 
@@ -1986,18 +2009,18 @@ end.simList <- function(x, unit, ...) {
     return(t)
 }
 
+#' @aliases simList-accessors-times
 #' @export
 #' @rdname simList-accessors-times
-#' @aliases simList-accessors-times
 setGeneric("end<-", function(x, value) {
   standardGeneric("end<-")
 })
 
-#' @name end<-
 #' @aliases end<-,simList-method
-#' @export
-#' @rdname simList-accessors-times
 #' @aliases simList-accessors-times
+#' @export
+#' @name end<-
+#' @rdname simList-accessors-times
 setReplaceMethod(
   "end",
   signature = "simList",
@@ -2012,11 +2035,10 @@ setReplaceMethod(
 })
 
 ################################################################################
-#' @inheritParams times
+#' @export
 #' @importFrom stats start
 #' @include simList-class.R
 #' @include times.R
-#' @export
 #' @rdname simList-accessors-times
 start <- function(x, ...) UseMethod("start")
 
@@ -2089,8 +2111,6 @@ setReplaceMethod(
 }
 
 ################################################################################
-#' @inheritParams times
-#'
 #' @details \code{timeunit} will extract the current units of the time used in a
 #' simulation (i.e., within a \code{spades} call).
 #' If it is set within a \code{simInit}, e.g.,
@@ -2114,37 +2134,36 @@ setReplaceMethod(
 #' \code{dfortnight <- function(x) lubridate::duration(dday(14))}
 #' can be placed anywhere in the search path or in a module.
 #'
-#' @include simList-class.R
-#' @export
-#' @rdname simList-accessors-times
 #' @aliases simList-accessors-times
-#'
+#' @export
+#' @include simList-class.R
+#' @rdname simList-accessors-times
 setGeneric("timeunit", function(x) {
   standardGeneric("timeunit")
 })
 
-#' @rdname simList-accessors-times
 #' @aliases simList-accessors-times
 #' @export
+#' @rdname simList-accessors-times
 setMethod("timeunit",
           signature = "simList",
           definition = function(x) {
             return(x@simtimes[["timeunit"]])
 })
 
+#' @aliases simList-accessors-times
 #' @export
 #' @rdname simList-accessors-times
-#' @aliases simList-accessors-times
 setGeneric("timeunit<-",
            function(x, value) {
              standardGeneric("timeunit<-")
 })
 
-#' @name timeunit<-
 #' @aliases timeunit<-,simList-method
-#' @export
-#' @rdname simList-accessors-times
 #' @aliases simList-accessors-times
+#' @export
+#' @name timeunit<-
+#' @rdname simList-accessors-times
 setReplaceMethod(
   "timeunit",
   signature = "simList",
@@ -2160,8 +2179,6 @@ setReplaceMethod(
 })
 
 ################################################################################
-#' @inheritParams times
-#'
 #' @details \code{timeunits} will extract the current units of the time of all
 #' modules used in a simulation.
 #' This is different from \code{timeunit} because it is not necessarily
@@ -2172,18 +2189,17 @@ setReplaceMethod(
 #' than \code{time(sim)}. So as a module developer, it is advantageous to
 #' write out the longer one, minimizing the looking up that R must do.
 #'
+#' @aliases simList-accessors-times
 #' @include simList-class.R
 #' @export
 #' @rdname simList-accessors-times
-#'
-#' @aliases simList-accessors-times
 setGeneric("timeunits", function(x) {
   standardGeneric("timeunits")
 })
 
+#' @aliases simList-accessors-times
 #' @export
 #' @rdname simList-accessors-times
-#' @aliases simList-accessors-times
 setMethod(
   "timeunits",
   signature = "simList",
@@ -2248,15 +2264,13 @@ setMethod(
 #' @importFrom stats setNames
 #' @include simList-class.R
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
-#'
 setGeneric("events", function(sim, unit) {
   standardGeneric("events")
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setMethod(
   "events",
   signature = c("simList", "character"),
@@ -2275,9 +2289,9 @@ setMethod(
     return(obj)
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setMethod("events",
           signature = c("simList", "missing"),
           definition = function(sim, unit) {
@@ -2285,18 +2299,18 @@ setMethod("events",
             return(res)
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setGeneric("events<-",
            function(sim, value) {
              standardGeneric("events<-")
 })
 
-#' @name events<-
 #' @aliases events<-,simList-method
 #' @aliases simList-accessors-events
 #' @export
+#' @name events<-
 #' @rdname simList-accessors-events
 setReplaceMethod(
   "events",
@@ -2322,17 +2336,16 @@ setReplaceMethod(
 })
 
 #############################
-#' @rdname simList-accessors-events
 #' @aliases simList-accessors-events
-#'
 #' @export
+#' @rdname simList-accessors-events
 setGeneric("conditionalEvents", function(sim, unit) {
   standardGeneric("conditionalEvents")
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setMethod(
   "conditionalEvents",
   signature = c("simList", "character"),
@@ -2366,9 +2379,9 @@ setMethod(
     }
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setMethod("conditionalEvents",
           signature = c("simList", "missing"),
           definition = function(sim, unit) {
@@ -2379,20 +2392,20 @@ setMethod("conditionalEvents",
 ################################################################################
 #' @inheritParams events
 #'
+#' @aliases simList-accessors-events
 #' @export
 #' @importFrom data.table rbindlist
 #' @importFrom stats setNames
 #' @include simList-class.R
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 #'
 setGeneric("current", function(sim, unit) {
   standardGeneric("current")
 })
 
-#' @rdname simList-accessors-events
-#' @export
 #' @aliases simList-accessors-events
+#' @export
+#' @rdname simList-accessors-events
 setMethod(
   "current",
   signature = c("simList", "character"),
@@ -2413,9 +2426,9 @@ setMethod(
     return(rbindlist(list(out)))
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setMethod("current",
           signature = c("simList", "missing"),
           definition = function(sim, unit) {
@@ -2423,19 +2436,19 @@ setMethod("current",
             return(out)
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setGeneric("current<-",
            function(sim, value) {
              standardGeneric("current<-")
 })
 
-#' @name current<-
 #' @aliases current<-,simList-method
-#' @export
-#' @rdname simList-accessors-events
 #' @aliases simList-accessors-events
+#' @export
+#' @name current<-
+#' @rdname simList-accessors-events
 setReplaceMethod("current",
                  signature = "simList",
                  function(sim, value) {
@@ -2450,21 +2463,22 @@ setReplaceMethod("current",
 
 ################################################################################
 #' @inheritParams events
-#' @include simList-class.R
+#' @param times Logical. Should this function report the clockTime
+#'
+#' @aliases simList-accessors-events
+#' @export
 #' @importFrom data.table := data.table
 #' @importFrom stats setNames
-#' @param times Logical. Should this function report the clockTime
-#' @export
+#' @include simList-class.R
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setGeneric("completed", function(sim, unit, times = TRUE) {
   standardGeneric("completed")
 })
 
-#' @rdname simList-accessors-events
-#' @export
 #' @aliases simList-accessors-events
+#' @export
 #' @importFrom data.table rbindlist set setkeyv :=
+#' @rdname simList-accessors-events
 setMethod(
   "completed",
   signature = c("simList", "character"),
@@ -2496,9 +2510,9 @@ setMethod(
     return(obj)
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setMethod("completed",
           signature = c("simList", "missing"),
           definition = function(sim, unit, times = TRUE) {
@@ -2506,19 +2520,19 @@ setMethod("completed",
             return(out)
 })
 
+#' @aliases simList-accessors-events
 #' @export
 #' @rdname simList-accessors-events
-#' @aliases simList-accessors-events
 setGeneric("completed<-",
            function(sim, value) {
              standardGeneric("completed<-")
 })
 
-#' @name completed<-
 #' @aliases completed<-,simList-method
-#' @export
-#' @rdname simList-accessors-events
 #' @aliases simList-accessors-events
+#' @export
+#' @name completed<-
+#' @rdname simList-accessors-events
 setReplaceMethod(
   "completed",
   signature = "simList",
@@ -2602,14 +2616,13 @@ setMethod(
 #'
 #' @return A sorted character vector of package names.
 #'
+#' @aliases simList-accessors-packages
+#' @author Alex Chubaty & Eliot McIntire
 #' @export
 #' @include simList-class.R
 #' @family functions to access elements of a 'simList' object
 #' @rdname packages
 #'
-#' @author Alex Chubaty & Eliot McIntire
-#' @aliases simList-accessors-packages
-#'
 # igraph exports %>% from magrittr
 setGeneric("packages", function(sim, modules, paths, filenames, envir,
                                 clean = FALSE, ...) {
@@ -2629,6 +2642,7 @@ setMethod(
       depsInSim <- list(NULL)
     } else {
       depsInSim <- sim@depends@dependencies
+      if (is.null(depsInSim[[1]])) return(character()) # basically for empty simList objects
     }
 
     if (!is.null(depsInSim[[1]])) { # check within dependencies slot for any elements,
@@ -2892,17 +2906,17 @@ setMethod("citation",
 })
 
 ################################################################################
-#' @inheritParams times
+#' @export
 #' @include simList-class.R
 #' @include times.R
-#' @export
 #' @rdname simList-accessors-times
 elapsedTime <- function(x, ...) UseMethod("elapsedTime")
 
+#' @param byEvent Logical. If \code{TRUE}, the elapsed time will be by module and event;
+#'                \code{FALSE} will report only by module. Default is \code{TRUE}.
+#'
 #' @export
 #' @rdname simList-accessors-times
-#' @param byEvent Logical. If \code{TRUE}, the elapsed time will be by module and event;
-#'                \code{FALSE} will report only by module. Default is \code{TRUE}
 elapsedTime.simList <- function(x, byEvent = TRUE, ...) {
   comp <- completed(x)
 
