@@ -24,7 +24,7 @@ if (getRversion() >= "3.1.0") {
 #'
 #' @author Alex Chubaty
 #' @export
-#' @importFrom data.table data.table rbindlist setkey
+#' @importFrom data.table data.table rbindlist setkey fread
 #' @importFrom stringi stri_pad_right stri_pad stri_length
 #' @importFrom reproducible Cache
 #' @importFrom utils write.table
@@ -68,7 +68,6 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
     st[["current"]] <- sim@simtimes[["end"]] + 1
     slot(sim, "simtimes", check = FALSE) <- st
   } else {
-
     # if the current time is greater than end time, then don't run it
     if (cur[["eventTime"]] <= sim@simtimes[["end"]]) {
       fnEnv <- sim@.xData[[curModuleName]]
@@ -94,7 +93,7 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
         for (i in seq_along(debug)) {
           if (isTRUE(debug[[i]]) | debug[[i]] == "current" | debug[[i]] == "step") {
             if (length(cur) > 0) {
-              if(debug[[i]] == "step") readline("Press any key to continue...")
+              if (debug[[i]] == "step") readline("Press any key to continue...")
 
               evnts1 <- data.frame(current(sim))
               widths <- stri_length(format(evnts1))
@@ -120,10 +119,11 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
                          " | total elpsd: ", format(Sys.time() - sim@.xData$._startClockTime, digits = 2),
                          " | ", paste(unname(current(sim)), collapse = ' ')))
           } else if (debug[[i]] == 2) {
-            compareTime <- if (is.null(attr(sim, "completedCounter")) || attr(sim, "completedCounter")==1) {
+            compareTime <- if (is.null(attr(sim, "completedCounter")) ||
+                               attr(sim, "completedCounter") == 1) {
               sim@.xData$._startClockTime
             } else {
-              .POSIXct(sim@completed[[as.character(attr(sim, "completedCounter")-1)]]$._clockTime)
+              .POSIXct(sim@completed[[as.character(attr(sim, "completedCounter") - 1)]]$._clockTime)
             }
             print(paste0(format(Sys.time(), format = "%H:%M:%S"),
                          " | elpsd: ", format(Sys.time() - compareTime, digits = 2),
@@ -133,14 +133,13 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
           } else if (grepl(debug[[i]], pattern = "\\(")) {
             print(eval(parse(text = debug[[i]])))
           } else if (any(debug[[i]] %in% cur[c("moduleName", "eventType")])) {
-            if(is.environment(fnEnv)) {
+            if (is.environment(fnEnv)) {
               if (all(debug %in% cur[c("moduleName", "eventType")])) {
                 debugonce(get(paste0("doEvent.", curModuleName), envir = fnEnv))
                 on.exit(get(paste0("doEvent.", curModuleName), envir = fnEnv))
               }
             }
           } else if (!any(debug[[i]] == c("browser"))) {
-
             tryCatch(print(do.call(debug[[i]], list(sim))), error = function(x) NULL)
           }
         }
@@ -149,10 +148,8 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
       # if the moduleName exists in the simList -- i.e,. go ahead with doEvent
       if (curModuleName %in% sim@modules) {
         if (curModuleName %in% core) {
-          sim <- get(moduleCall)(sim, cur[["eventTime"]],
-                                 cur[["eventType"]])
+          sim <- get(moduleCall)(sim, cur[["eventTime"]], cur[["eventType"]])
         } else {
-
           # for future caching of modules
           cacheIt <- FALSE
           a <- sim@params[[curModuleName]][[".useCache"]]
@@ -174,13 +171,20 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
             }
           }
 
+          showSimilar <- if (is.null(sim@params[[curModuleName]][[".showSimilar"]]) ||
+            isTRUE(is.na(sim@params[[curModuleName]][[".showSimilar"]]))) {
+              isTRUE(getOption("reproducible.showSimilar", FALSE))
+            } else {
+              isTRUE(sim@params[[curModuleName]][[".showSimilar"]])
+            }
+
           # This is to create a namespaced module call
           if (!.pkgEnv[["skipNamespacing"]])
             .modifySearchPath(sim@depends@dependencies[[curModuleName]]@reqdPkgs,
                               removeOthers = FALSE)
 
-          sim <- .runEvent(sim, cacheIt, debug,
-                           moduleCall, fnEnv, cur, notOlderThan)
+          sim <- .runEvent(sim, cacheIt, debug, moduleCall, fnEnv, cur, notOlderThan,
+                           showSimilar = showSimilar)
 
           if (!exists(curModuleName, envir = sim, inherits = FALSE))
             stop("The module named ", curModuleName, " just corrupted the object with that ",
@@ -195,20 +199,13 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
                  cur[["eventType"]])
 
           if (!exists("mod", envir = sim@.envir[[curModuleName]], inherits = FALSE))
-            stop("The module named ", curModuleName, " just deleted the object named 'mod' from sim$",
-                 curModuleName,". ",
+            stop("The module named ", curModuleName, " just deleted the object named 'mod' from ",
+                 "sim$", curModuleName, ". ",
                  "Please remove the section of code that does this in the event named: ",
                  cur[["eventType"]])
-
         }
       } else {
-        stop(
-          paste(
-            "Invalid module call. The module `",
-            curModuleName,
-            "` wasn't specified to be loaded."
-          )
-        )
+        stop("Invalid module call. The module `", curModuleName, "` wasn't specified to be loaded.")
       }
 
       # add to list of completed events
@@ -242,7 +239,6 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
           # faster to use assign
           assign(as.character(attr(sim, "completedCounter")), value = cur, envir = sim@completed)
           #sim@completed[[as.character(attr(sim, "completedCounter"))]] <- cur
-
         } else {
           attr(sim, "completedCounter") <- 1
           attr(sim, "completedSize") <- 2
@@ -252,7 +248,6 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
 
       # current event completed, replace current with empty
       slot(sim, "current", check = FALSE) <- list() # is a list
-
     } else {
       # update current simulated time and event
       # Test replacement for speed
@@ -265,12 +260,10 @@ doEvent <- function(sim, debug = FALSE, notOlderThan) {
       slot(sim, "events", check = FALSE) <- append(list(sim@current), sim@events) # will be a list b/c append
       slot(sim, "current", check = FALSE) <- list() # is a list
     }
-
   }
 
   if (exists("objectSynonyms", envir = sim, inherits = FALSE)) {
     sim <- .checkObjectSynonyms(sim)
-
   }
 
   return(invisible(sim))
@@ -365,14 +358,14 @@ scheduleEvent <- function(sim,
     if (!is.na(eventTime)) {
       if (eventTime < 0) {
           stop("You have tried to schedule an event with negative time. You cannot do this. ",
-               " Reschedule event (",eventType," event in ", moduleName," module) with positive time.")
+               " Reschedule event (", eventType," event in ", moduleName, " module) with positive time.")
       }
       eventTimeInSeconds <- calculateEventTimeInSeconds(sim, eventTime, moduleName)
       attr(eventTimeInSeconds, "unit") <- "second"
 
       if (eventTimeInSeconds < sim@simtimes$start)
         stop("You have tried to schedule an event before start(sim). You cannot do this.",
-             " Reschedule event (",eventType," event in ", moduleName," module) at or after start(sim).")
+             " Reschedule event (", eventType," event in ", moduleName, " module) at or after start(sim).")
 
       newEventList <- list(list(
         eventTime = eventTimeInSeconds,
@@ -434,16 +427,16 @@ scheduleEvent <- function(sim,
 #'      It can access objects in the \code{simList} by using functions of \code{sim},
 #'      e.g., \code{"sim$age > 1"}
 #'
-#' @return Returns the modified \code{simList} object, i.e., \code{sim$._conditionalEvents}
+#' @return Returns the modified \code{simList} object, i.e., \code{sim$._conditionalEvents}.
 #'
 #' This conditional event queue will be assessed at every single event in the normal event
-#' queue. If there are no conditional events, then \code{spades} will proceed as normal. As
-#' conditional event conditions are found to be true, then it will trigger a call to
-#' \code{scheduleEvent(...)} with the current time passed to \code{eventTime} \emph{and} it will
-#' remove the conditional event from the conditional queue. If the user
-#' would like the triggered conditional event to occur as the very next event, then
-#' a possible strategy would be to set \code{eventPriority} of the conditional event to
-#' very low or even negative to ensure it gets inserted at the top of the event queue.
+#' queue. If there are no conditional events, then \code{spades} will proceed as normal.
+#' As conditional event conditions are found to be true, then it will trigger a call to
+#' \code{scheduleEvent(...)} with the current time passed to \code{eventTime} \emph{and}
+#' it will remove the conditional event from the conditional queue.
+#' If the user would like the triggered conditional event to occur as the very next event,
+#' then a possible strategy would be to set \code{eventPriority} of the conditional event
+#' to very low or even negative to ensure it gets inserted at the top of the event queue.
 #'
 #' @importFrom data.table setkey
 #' @include priority.R
@@ -614,7 +607,6 @@ scheduleConditionalEvent <- function(sim,
 #' @return Invisibly returns the modified \code{simList} object.
 #'
 #' @seealso \code{\link{SpaDES.core-package}},
-#' \code{\link{experiment}} for using replication with \code{spades},
 #' \code{\link{simInit}}, and the caching vignette (very important for reproducibility):
 #' \url{https://CRAN.R-project.org/package=SpaDES.core/vignettes/iii-cache.html} which
 #' uses \code{\link[reproducible]{Cache}}.
@@ -639,8 +631,7 @@ scheduleConditionalEvent <- function(sim,
 #' the function will simply return the result that would have come if it had
 #' been rerun. Use this with caution, as it will return exactly the result from
 #' a previous run, even if there is stochasticity internally.
-#' Caching is only based on the input simList. See also \code{experiment} for
-#' the same mechanism, but it can be used with replication.
+#' Caching is only based on the input simList.
 #' See also the vignette on caching for examples.
 #'
 #' @section \code{debug}:
@@ -763,16 +754,42 @@ setMethod(
     # set the options("spades.xxxPath") to the values in the sim@paths
     oldGetPaths <- getPaths()
     do.call(setPaths, append(sim@paths, list(silent = TRUE)))
-    on.exit({do.call(setPaths, append(list(silent = TRUE), oldGetPaths))}, add = TRUE)
+    on.exit({
+      do.call(setPaths, append(list(silent = TRUE), oldGetPaths))
+    }, add = TRUE)
 
-    sim@.xData[["._startClockTime"]] <- Sys.time()
+    if (!is.null(sim@.xData[["._randomSeed"]])) {
+      message("Resetting .Random.seed of session because sim$._randomSeed is not NULL. ",
+              "To get a different seed, run: sim$._randomSeed <- NULL to clear it.")
+      assign(".Random.seed", sim@.xData$._randomSeed[[1]], envir = .GlobalEnv)
+      if (!is.null(sim$._rng.kind)) {
+        do.call("RNGkind", as.list(sim$._rng.kind))
+      }
+      sim@.xData[["._randomSeed"]] <- NULL
+      sim@.xData[["._rng.kind"]] <- NULL
+    }
+    if (is.null(sim@.xData[["._startClockTime"]]))
+      sim@.xData[["._startClockTime"]] <- Sys.time()
+    if (is.null(sim@.xData[["._simRndString"]]))
+      sim@.xData[["._simRndString"]] <- rndstr(1, 8, characterFirst = TRUE)
     .pkgEnv$searchPath <- search()
-    .pkgEnv[["spades.browserOnError"]] <-
-      (interactive() & !identical(debug, FALSE) & getOption("spades.browserOnError"))
+    .pkgEnv[["spades.browserOnError"]] <- (interactive() & !identical(debug, FALSE) &
+                                             getOption("spades.browserOnError"))
     .pkgEnv[["spades.nCompleted"]] <- getOption("spades.nCompleted")
     .pkgEnv[["skipNamespacing"]] <- !getOption("spades.switchPkgNamespaces")
     .pkgEnv[["spades.keepCompleted"]] <- getOption("spades.keepCompleted", TRUE)
 
+    # Memory Use
+    # memory estimation of each event/sim
+    if (getOption("spades.memoryUseInterval", 0) > 0) {
+      originalPlan <- future::plan()
+      sim <- memoryUseSetup(sim, originalPlan)
+      # Do the on.exit stuff
+      on.exit({
+        sim <- memoryUseOnExit(sim, originalPlan)
+      }, add = TRUE)
+    }
+
     # timeunits gets accessed every event -- this should only be needed once per simList
     sim@.xData$.timeunits <- timeunits(sim)
     on.exit({
@@ -786,12 +803,27 @@ setMethod(
           }
           messageInterrupt1(recoverMode)
         } else {
-          message(crayon::magenta("simList saved in\n",crayon::blue("SpaDES.core:::.pkgEnv$.sim"),
-                                  "\nIt will be deleted at next spades call"))
+          message(crayon::magenta("simList saved in\n",
+                                  crayon::blue("SpaDES.core:::.pkgEnv$.sim"),
+                                  "\nIt will be deleted at next spades() call."))
         }
         .pkgEnv$.sim <- sim # no copy of objects -- essentially 2 pointers throughout
         .pkgEnv$.cleanEnd <- NULL
       }
+      # For restarting R -- a few extra pieces, including saving the simList as the last thing
+      if (!is.null(sim$._restartRList)) {
+        sim@simtimes[["current"]] <- sim@events[[1]]$eventTime
+        sim$._restartRList$.spadesCall <- match.call()
+
+        restartFormals <- formals(restartR)
+        # can change end(sim) back to original now because we are already ending
+        end(sim) <- sim$._restartRList$endOrig
+        restartR(sim = sim,
+                 reloadPkgs = getOption("spades.restartR.reloadPkgs", restartFormals$reloadPkgs),
+                 .First = getOption("spades.restartR..First", restartFormals$.First),
+                 .RDataFile = getOption("spades.restartR.RDataFilename", sim$._restartRList$simFilename),
+                 restartDir = getOption("spades.restartR.restartDir", restartFormals$restartDir))
+      }
     }, add = TRUE)
 
     if (!is.null(.plotInitialTime)) {
@@ -850,19 +882,23 @@ setMethod(
 
     sim@.xData[["._firstEventClockTime"]] <- Sys.time()
 
-    # This was introduced when sim@completed became an environment for speed purposes (list got slow as size increased)
-    # This is an attempt to deal with the expected behaviour of a list -- i.e., delete it if this appears to be
-    #   the original sim object again passed in
+    # This was introduced when sim@completed became an environment for speed purposes
+    # (list got slow as size increased)
+    # This is an attempt to deal with the expected behaviour of a list --
+    # i.e., delete it if this appears to be the original sim object again passed in
     if (length(sim@completed)) {
       existingCompleted <- sort(as.integer(ls(sim@completed, sorted = FALSE)))
       prevStart <- get(as.character(existingCompleted[1]), envir = sim@completed)
       prevEnd <- get(as.character(existingCompleted[length(existingCompleted)]), envir = sim@completed)
-      if (start(sim, unit = attr(prevStart[["eventTime"]], "unit")) <= prevStart[["eventTime"]])
+      if (start(sim, unit = attr(prevStart[["eventTime"]], "unit")) <= prevStart[["eventTime"]] &&
+        (time(sim, unit = attr(prevStart[["eventTime"]], "unit")) ==
+           start(sim, unit = attr(prevStart[["eventTime"]], "unit"))))
         sim@completed <- new.env(parent = emptyenv())
     }
 
     recoverModeWrong <- getOption("spades.recoverMode")
-    if (!is.null(recoverModeWrong)) warning("Please set options('recoveryMode') with a 'y', not options('recoverMode')")
+    if (!is.null(recoverModeWrong))
+      warning("Please set options('recoveryMode') with a 'y', not options('recoverMode')")
     recoverMode <- getOption("spades.recoveryMode", FALSE)
 
     if (recoverMode > 0) {
@@ -893,7 +929,6 @@ setMethod(
               condEventsToOmit <- c(condEventsToOmit, condNum)
             }
           }
-
         }
         if (length(condEventsToOmit)) {
           sim$._conditionalEvents <- sim$._conditionalEvents[-condEventsToOmit]
@@ -939,16 +974,19 @@ setMethod(
     if (cache) {
       return(
         do.call(quote = TRUE, Cache,
-                args = append(list(
-                  spades,
-                  sim = sim,
-                  debug = debug,
-                  progress = progress,
-                  .plotInitialTime = .plotInitialTime,
-                  .saveInitialTime = .saveInitialTime,
-                  omitArgs = omitArgs, notOlderThan = notOlderThan),
-                  #cacheRepo = sim@paths$cachePath),
-                  dots))
+                args = append(
+                  list(
+                    spades,
+                    sim = sim,
+                    debug = debug,
+                    progress = progress,
+                    .plotInitialTime = .plotInitialTime,
+                    .saveInitialTime = .saveInitialTime,
+                    omitArgs = omitArgs, notOlderThan = notOlderThan
+                  ),
+                  dots
+               )
+        )
       )
     } else {
       return(
@@ -964,7 +1002,8 @@ setMethod(
 })
 
 #' @keywords internal
-.runEvent <- function(sim, cacheIt, debug, moduleCall, fnEnv, cur, notOlderThan) {
+.runEvent <- function(sim, cacheIt, debug, moduleCall, fnEnv, cur, notOlderThan,
+                      showSimilar) {
   if (cacheIt) { # means that a module or event is to be cached
     createsOutputs <- sim@depends@dependencies[[cur[["moduleName"]]]]@outputObjects$objectName
     fns <- ls(fnEnv, all.names = TRUE)
@@ -987,6 +1026,7 @@ setMethod(
                      notOlderThan = notOlderThan,
                      outputObjects = moduleSpecificOutputObjects,
                      classOptions = classOptions,
+                showSimilar = showSimilar,
                      cacheRepo = sim@paths[["cachePath"]]))
   } else {
     # Faster just to pass the NULL and just call it directly inside .runEvent
@@ -1016,9 +1056,8 @@ setMethod(
              envir = sim@.xData[[cur[["moduleName"]]]])
         numTries <- 0
       } else {
-        message("There was an error in the code in the ", moduleCall,
-                ". Entering browser. You can correct it and press c to continue",
-                " or Q to quit")
+        message("There was an error in the code in the ", moduleCall, ".\n",
+                "Entering browser. You can correct it and press c to continue or Q to quit.")
         debugonce(get(moduleCall, envir = fnEnv))
       }
     } else {
@@ -1063,6 +1102,7 @@ calculateEventTimeInSeconds <- function(sim, eventTime, moduleName) {
 }
 
 #' @keywords internal
+#' @importFrom stats runif
 recoverModePre <- function(sim, rmo = NULL, allObjNames = NULL, recoverMode) {
   if (is.null(allObjNames)) {
     allObjNames <- outputObjectNames(sim)
@@ -1095,7 +1135,9 @@ recoverModePre <- function(sim, rmo = NULL, allObjNames = NULL, recoverMode) {
   }
   endTime <- Sys.time()
   rmo$preEvents <- sim@events
-  rmo$randomSeed <- append(list(.Random.seed), rmo$randomSeed)
+  if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) tmp <- runif(1)
+  rmo$randomSeed <- append(list(get(".Random.seed", envir = .GlobalEnv, inherits = FALSE)),
+                           rmo$randomSeed)
 
   rmo$recoverModeTiming <- rmo$recoverModeTiming + (endTime - startTime)
 
@@ -1117,7 +1159,7 @@ recoverModeOnExit <- function(sim, rmo, recoverMode) {
   rmo$postEvents <- sim@events
   rmo$addedEvents <- append(list(setdiff(rmo$postEvents, rmo$preEvents)), rmo$addedEvents)
   sim@.xData$.addedEvents <- rmo$addedEvents
-  sim@.xData$.randomSeed <- rmo$randomSeed
+  sim@.xData$._randomSeed <- rmo$randomSeed
   message(crayon::magenta(paste0("Setting options('spades.recoveryMode' = ",recoverMode,") used ",
                                  format(rmo$recoverModeTiming, units = "auto", digits = 3),
                                  " and ", format(recoverableObjsSize, units = "auto"))))
