@@ -1,6 +1,20 @@
 ## be sure to update the 'Package Options' section of the package help file
 ##   in R/spades-core-package.R
 ##
+# e = new.env()
+#
+# reg.finalizer(e, function(e) {
+#   message('Object Bye!')
+# }, onexit = TRUE)
+#
+#
+# finalize <- function(env) {
+#   print(ls(env))
+#   message("Bye from Name space Finalizer")
+# }
+
+.spadesTempDir <- file.path(tempdir(), "SpaDES")
+
 .onLoad <- function(libname, pkgname) {
   ## set options using the approach used by devtools
   opts <- options()
@@ -9,8 +23,10 @@
     spades.browserOnError = FALSE,
     #spades.cachePath = reproCachePath,
     spades.debug = 1, # TODO: is this the best default? see discussion in #5
+    spades.futurePlan = "callr",
     spades.inputPath = file.path(.spadesTempDir, "inputs"),
     spades.lowMemory = FALSE,
+    spades.memoryUseInterval = 0,
     spades.moduleCodeChecks = list(
       skipWith = TRUE,
       suppressNoLocalFun = TRUE,
@@ -23,6 +39,9 @@
     spades.nCompleted = 10000L,
     spades.outputPath = file.path(.spadesTempDir, "outputs"),
     spades.recoveryMode = 1,
+    spades.restartRInterval = 0,
+    spades.restartR.clearFiles = TRUE,
+    spades.restartR.RDataFilename = "sim.restartR.RData",
     spades.saveSimOnExit = TRUE,
     spades.switchPkgNamespaces = FALSE,
     spades.tolerance = .Machine$double.eps ^ 0.5,
@@ -56,12 +75,19 @@
   ## import functions using backports:
   backports::import(pkgname, "isFALSE")
 
+  # parent <- parent.env(environment())
+  # print(str(parent))
+  #reg.finalizer(parent, finalize, onexit= TRUE)
+
   invisible()
 }
 
 #' @importFrom reproducible normPath
 #' @importFrom utils packageVersion
 .onAttach <- function(libname, pkgname) {
+  # module template path
+  .pkgEnv[["templatePath"]] <- system.file("templates", package = "SpaDES.core")
+
   if (interactive()) {
     packageStartupMessage("Using SpaDES.core version ", utils::packageVersion("SpaDES.core"), ".")
     a <- capture.output(setPaths(), type = "message")
@@ -91,7 +117,6 @@
   #                   env = as.environment("package:SpaDES.core")
   # )
   # lockBinding("Paths", as.environment("package:SpaDES.core"))
-
 }
 
 .onUnload <- function(libpath) {
@@ -109,8 +134,3 @@
     options(spades.outputPath = NULL)
   }
 }
-
-.spadesTempDir <- file.path(tempdir(), "SpaDES")
-
-
-
